This function can be used to locate geographic information given a geographic point.
It does not provide an address like a reverse-geocoder
To obtain current valid benchmarks, use the cxy_benchmarks() function
To use this function, you must specify a valid vintage for your benchmark. You may use
the cxy_vintages() function to obtain valid Vintages for a given benchmark.
See vignette('censusxy') for a full walkthrough.